==> nextcloud-29.0.12.tgz: nextcloud/apps/viewer/l10n/et_EE.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Vaataja",
    "Simple file viewer with slideshow for media" : "Lihtne failivaataja koos meedia esitlusega",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Näidake oma viimaseid puhkusefotosid ja -videoid nagu filmides, näidake pilku oma viimasest romaanist otse oma Nextcloudist, valige tänu lemmikfailide otsesele eelvaatele oma kollektsiooni parim GIF ja palju muud!",
    "Your browser does not support audio." : "Su brauser ei toeta heli.",
    "Error loading {name}" : "Viga {name} laadimisel",
    "Image saved" : "Pilt salvestatud",
    "Error saving image" : "Viga pildi salvestamisel",
    "Unsaved changes" : "Salvestamata muutused",
    "Drop changes" : "Tühista muudatused",
    "Play the live photo" : "Mängi liikuvat pilti",
    "LIVE" : "OTSE",
    "Your browser does not support videos." : "Su brauser ei toeta videoid.",
    "Edit" : "Redigeeri",
    "Exit full screen" : "Välju täisekraanilt",
    "Full screen" : "Täisekraan",
    "Open sidebar" : "Ava külgriba",
    "Download" : "Lae alla",
    "Delete" : "Kustuta",
    "This file no longer exists" : "Seda faili enam ei eksisteeri",
    "There is no plugin available to display this file type" : "Selle failitüübi jaoks pole olemas vastavat vidinat",
    "View" : "Vaata",
    "Name" : "Nimi",
    "Save" : "Salvesta",
    "Save as" : "Salvesta kui",
    "Back" : "Tagasi",
    "Loading …" : "Laadimine ...",
    "Reset" : "Lähtesta",
    "All changes will be lost." : "Kõik muudatused kaovad.",
    "Are you sure you want to continue?" : "Kas oled kindel, et tahad jätkata?",
    "Cancel" : "Loobu",
    "Apply" : "Rakenda",
    "Warning" : "Hoiatus",
    "Confirm" : "Kinnita",
    "Discard changes" : "Hülga muudatused",
    "Undo" : "Tühista",
    "Redo" : "Tee uuesti",
    "Show original image" : "Näita algpilti",
    "Zoom in" : "Suumi sisse",
    "Zoom out" : "Suumi välja",
    "Toggle zoom menu" : "Luba suumi menüü",
    "Adjust" : "Kohanda",
    "Fine-tune" : "Peenhäälestus",
    "Filters" : "Filtrid",
    "Watermark" : "Vesimärk",
    "Draw" : "Joonista",
    "Resize" : "Muuda suurust",
    "Image name" : "Pildi nimi",
    "Invalid image." : "Mittesobiv pilt.",
    "Error while uploading the image." : "Viga pildi üles laadimisel.",
    "are not images" : "ei ole pildid",
    "is not an image" : "ei ole pilt",
    "to be uploaded" : "ootab üleslaadimist",
    "Crop" : "Lõika",
    "Original" : "Algne",
    "Custom" : "Kohandatud",
    "Square" : "Ruut",
    "Landscape" : "Horisontaalne",
    "Portrait" : "Vertikaalne",
    "Ellipse" : "Ellips",
    "Classic TV" : "Klassikaline TV",
    "CinemaScope" : "KinoSkoop",
    "Arrow" : "Nool",
    "Blur" : "Hägusus",
    "Brightness" : "Heledus",
    "Contrast" : "Kontrast",
    "Un-flip X" : "Keera tagasi X",
    "Flip X" : "Keera X",
    "Un-flip Y" : "Keera tagasi Y",
    "Flip Y" : "Keera Y",
    "HSV" : "HSV",
    "Hue" : "Toon",
    "Saturation" : "Saturatsioon",
    "Value" : "Väärtus",
    "Image" : "Pilt",
    "Importing …" : "Impordin ...",
    "+ Add image" : "+ Lisa Pilt",
    "Upload image" : "Lae pilt üles",
    "From gallery" : "Galeriist",
    "Line" : "Joon",
    "Pen" : "Pastakas",
    "Polygon" : "Hulknurk",
    "Sides" : "Küljed",
    "Rectangle" : "Ristkülik",
    "Corner Radius" : "Nurga Raadius",
    "Width in pixels" : "Laius pikslites",
    "Height in pixels" : "Kõrgus pikslites",
    "Toggle ratio lock" : "Luba suhte lukk",
    "Reset to original image size" : "Lähesta algseks pildi suuruseks",
    "Rotate" : "Keera",
    "Text" : "Tekst",
    "Text spacing" : "Teksti vahede suurus",
    "Text alignment" : "Teksti keskpunkt",
    "Font family" : "Fondi perekond",
    "Size" : "Suurus",
    "Letter spacing" : "Tähtede vahede suurus",
    "Line height" : "Joone kõrgus",
    "Warmth" : "Soojus",
    "+ Add watermark" : "+ Lisa vesimärk",
    "+ Add text watermark" : "+ Lisa teksti vesimärk",
    "Choose watermark type" : "Vali vesimärgi tüüp",
    "Upload watermark" : "Lae vesimärk üles",
    "Add as text" : "Lisa tekstina",
    "Padding" : "Küljendus",
    "Paddings" : "Küljendused",
    "Shadow" : "Varjud",
    "Horizontal" : "Horisontaalne",
    "Vertical" : "Vertikaalne",
    "Opacity" : "Läbipaistmatus",
    "Transparency" : "Läbipaistvus",
    "Position" : "Asukoht",
    "Stroke" : "Liigutus",
    "Save image as" : "Salvesta pilt kui",
    "Extension" : "Laiend",
    "Format" : "Formaat",
    "Name is required." : "Nimi on nõutud.",
    "Quality" : "Kvaliteet",
    "Saved image size (width x height)" : "Salvestasin pildi suuruse (laius x kõrgus)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Pane tähele, et valitud kärpimisala on väiksem kui rakendatud suuruse muutmine, mis võib põhjustada kvaliteedi langust",
    "Actual size (100%)" : "Tegelik suurus (100%)",
    "Fit size" : "Mahuta suurus",
    "Select image to add …" : "Vali pilt mida lisada ...",
    "Failed to load image." : "Pildi avamine ebaõnnestus.",
    "Menu" : "Menüü",
    "Width" : "Laius",
    "Height" : "Kõrgus",
    "No preview available for this crop item" : "Selle lõiketüübi jaoks pole eelvaadet saadaval"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.10.tgz: nextcloud/apps/viewer/l10n/et_EE.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Vaataja",
    "Simple file viewer with slideshow for media" : "Lihtne failivaataja koos meedia esitlusega",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Näidake oma viimaseid puhkusefotosid ja -videoid nagu filmides, näidake pilku oma viimasest romaanist otse oma Nextcloudist, valige tänu lemmikfailide otsesele eelvaatele oma kollektsiooni parim GIF ja palju muud!",
    "Your browser does not support audio." : "Su brauser ei toeta heli.",
    "Error loading {name}" : "Viga {name} laadimisel",
    "Image saved" : "Pilt salvestatud",
    "Error saving image" : "Viga pildi salvestamisel",
    "Unsaved changes" : "Salvestamata muutused",
    "Drop changes" : "Tühista muudatused",
    "Play the live photo" : "Mängi liikuvat pilti",
    "LIVE" : "OTSE",
    "Your browser does not support videos." : "Su brauser ei toeta videoid.",
    "This file no longer exists" : "Seda faili enam ei eksisteeri",
    "There is no plugin available to display this file type" : "Selle failitüübi jaoks pole olemas vastavat vidinat",
    "Edit" : "Redigeeri",
    "Exit full screen" : "Välju täisekraanilt",
    "Full screen" : "Täisekraan",
    "Open sidebar" : "Ava külgriba",
    "Download" : "Laadi alla",
    "Delete" : "Kustuta",
    "View" : "Vaata",
    "Name" : "Nimi",
    "Save" : "Salvesta",
    "Save as" : "Salvesta kui",
    "Back" : "Tagasi",
    "Loading …" : "Laadimine ...",
    "Reset" : "Lähtesta",
    "All changes will be lost." : "Kõik muudatused kaovad.",
    "Are you sure you want to continue?" : "Kas oled kindel, et tahad jätkata?",
    "Cancel" : "Loobu",
    "Apply" : "Rakenda",
    "Warning" : "Hoiatus",
    "Confirm" : "Kinnita",
    "Discard changes" : "Hülga muudatused",
    "Undo" : "Tühista",
    "Redo" : "Tee uuesti",
    "Show original image" : "Näita algpilti",
    "Zoom in" : "Suumi sisse",
    "Zoom out" : "Suumi välja",
    "Toggle zoom menu" : "Luba suumi menüü",
    "Adjust" : "Kohanda",
    "Fine-tune" : "Peenhäälestus",
    "Filters" : "Filtrid",
    "Watermark" : "Vesimärk",
    "Draw" : "Joonista",
    "Resize" : "Muuda suurust",
    "Image name" : "Pildi nimi",
    "Invalid image." : "Mittesobiv pilt.",
    "Error while uploading the image." : "Viga pildi üles laadimisel.",
    "are not images" : "ei ole pildid",
    "is not an image" : "ei ole pilt",
    "to be uploaded" : "ootab üleslaadimist",
    "Crop" : "Kadreeri",
    "Original" : "Algne",
    "Custom" : "Kohandatud",
    "Square" : "Ruut",
    "Landscape" : "Horisontaalne",
    "Portrait" : "Vertikaalne",
    "Ellipse" : "Ellips",
    "Classic TV" : "Klassikaline TV",
    "CinemaScope" : "KinoSkoop",
    "Arrow" : "Nool",
    "Blur" : "Hägusus",
    "Brightness" : "Heledus",
    "Contrast" : "Kontrast",
    "Un-flip X" : "Keera tagasi X",
    "Flip X" : "Keera X",
    "Un-flip Y" : "Keera tagasi Y",
    "Flip Y" : "Keera Y",
    "HSV" : "HSV",
    "Hue" : "Toon",
    "Saturation" : "Saturatsioon",
    "Value" : "Väärtus",
    "Image" : "Pilt",
    "Importing …" : "Impordin ...",
    "+ Add image" : "+ Lisa Pilt",
    "Upload image" : "Laadi pilt üles",
    "From gallery" : "Galeriist",
    "Line" : "Joon",
    "Pen" : "Pastakas",
    "Polygon" : "Hulknurk",
    "Sides" : "Küljed",
    "Rectangle" : "Ristkülik",
    "Corner Radius" : "Nurga Raadius",
    "Width in pixels" : "Laius pikslites",
    "Height in pixels" : "Kõrgus pikslites",
    "Toggle ratio lock" : "Luba suhte lukk",
    "Reset to original image size" : "Lähesta algseks pildi suuruseks",
    "Rotate" : "Keera",
    "Text" : "Tekst",
    "Text spacing" : "Teksti vahede suurus",
    "Text alignment" : "Teksti keskpunkt",
    "Font family" : "Fondi perekond",
    "Size" : "Suurus",
    "Letter spacing" : "Tähtede vahede suurus",
    "Line height" : "Joone kõrgus",
    "Warmth" : "Soojus",
    "+ Add watermark" : "+ Lisa vesimärk",
    "+ Add text watermark" : "+ Lisa teksti vesimärk",
    "Choose watermark type" : "Vali vesimärgi tüüp",
    "Upload watermark" : "Laadi vesimärk üles",
    "Add as text" : "Lisa tekstina",
    "Padding" : "Küljendus",
    "Paddings" : "Küljendused",
    "Shadow" : "Varjud",
    "Horizontal" : "Horisontaalne",
    "Vertical" : "Vertikaalne",
    "Opacity" : "Läbipaistmatus",
    "Transparency" : "Läbipaistvus",
    "Position" : "Asukoht",
    "Stroke" : "Liigutus",
    "Save image as" : "Salvesta pilt kui",
    "Extension" : "Laiend",
    "Format" : "Vorming",
    "Name is required." : "Nimi on nõutud.",
    "Quality" : "Kvaliteet",
    "Saved image size (width x height)" : "Salvestasin pildi suuruse (laius x kõrgus)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Pane tähele, et valitud kadreerimisala on väiksem kui rakendatud suuruse muutmine, mis võib põhjustada kvaliteedikadu",
    "Actual size (100%)" : "Tegelik suurus (100%)",
    "Fit size" : "Mahuta suurus",
    "Select image to add …" : "Vali pilt mida lisada ...",
    "Failed to load image." : "Pildi avamine ebaõnnestus.",
    "Menu" : "Menüü",
    "Width" : "Laius",
    "Height" : "Kõrgus",
    "No preview available for this crop item" : "Selle kadreerimistüübi jaoks pole eelvaadet saadaval"
},
"nplurals=2; plural=(n != 1);");
